"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.buildStaticStandalone = buildStaticStandalone;
exports.buildStatic = buildStatic;

var _objectWithoutProperties2 = _interopRequireDefault(require("@babel/runtime/helpers/objectWithoutProperties"));

var _objectSpread2 = _interopRequireDefault(require("@babel/runtime/helpers/objectSpread"));

var _webpack = _interopRequireDefault(require("webpack"));

var _path = _interopRequireDefault(require("path"));

var _fs = _interopRequireDefault(require("fs"));

var _shelljs = _interopRequireDefault(require("shelljs"));

var _nodeLogger = require("@storybook/node-logger");

var _cli = require("./cli");

require("./config/env");

var _config = _interopRequireDefault(require("./config"));

var defaultFavIcon = require.resolve('./public/favicon.ico');

function buildStaticStandalone(options) {
  var outputDir = options.outputDir,
      staticDir = options.staticDir,
      watch = options.watch; // create output directory if not exists

  _shelljs.default.mkdir('-p', _path.default.resolve(outputDir)); // clear the static dir


  _shelljs.default.rm('-rf', _path.default.resolve(outputDir, 'static'));

  _shelljs.default.cp(defaultFavIcon, outputDir); // Build the webpack configuration using the `baseConfig`
  // custom `.babelrc` file and `webpack.config.js` files
  // NOTE changes to env should be done before calling `getBaseConfig`


  var config = (0, _config.default)((0, _objectSpread2.default)({
    configType: 'PRODUCTION',
    corePresets: [require.resolve('./core-preset-prod.js')]
  }, options));
  config.output.path = _path.default.resolve(outputDir); // copy all static files

  if (staticDir) {
    staticDir.forEach(function (dir) {
      if (!_fs.default.existsSync(dir)) {
        _nodeLogger.logger.error("Error: no such directory to load static files: ".concat(dir));

        process.exit(-1);
      }

      _nodeLogger.logger.info("=> Copying static files from: ".concat(dir));

      _shelljs.default.cp('-r', "".concat(dir, "/*"), outputDir);
    });
  } // compile all resources with webpack and write them to the disk.


  _nodeLogger.logger.info('Building storybook ...');

  var webpackCb = function webpackCb(err, stats) {
    if (err || stats.hasErrors()) {
      _nodeLogger.logger.error('Failed to build the storybook'); // eslint-disable-next-line no-unused-expressions


      err && _nodeLogger.logger.error(err.message); // eslint-disable-next-line no-unused-expressions

      stats && stats.hasErrors() && stats.toJson().errors.forEach(function (e) {
        return _nodeLogger.logger.error(e);
      });
      process.exitCode = 1;
    }

    _nodeLogger.logger.info('Building storybook completed.');
  };

  var compiler = (0, _webpack.default)(config);

  if (watch) {
    compiler.watch({}, webpackCb);
  } else {
    compiler.run(webpackCb);
  }
}

function buildStatic(_ref) {
  var packageJson = _ref.packageJson,
      loadOptions = (0, _objectWithoutProperties2.default)(_ref, ["packageJson"]);
  var cliOptions = (0, _cli.getProdCli)(packageJson);
  buildStaticStandalone((0, _objectSpread2.default)({}, cliOptions, loadOptions, {
    configDir: cliOptions.configDir || './.storybook',
    outputDir: cliOptions.outputDir || './storybook-static'
  }));
}