"use strict";

var _interopRequireDefault = require("@babel/runtime/helpers/interopRequireDefault");

Object.defineProperty(exports, "__esModule", {
  value: true
});
exports.default = void 0;

var _objectSpread2 = _interopRequireDefault(require("@babel/runtime/helpers/objectSpread"));

var _toConsumableArray2 = _interopRequireDefault(require("@babel/runtime/helpers/toConsumableArray"));

var _webpack = _interopRequireDefault(require("webpack"));

var _universalDotenv = require("universal-dotenv");

var _dotenvWebpack = _interopRequireDefault(require("dotenv-webpack"));

var _htmlWebpackPlugin = _interopRequireDefault(require("html-webpack-plugin"));

var _package = require("../../../package.json");

var _utils = require("./utils");

var _utils2 = require("../utils");

var _default = function _default(_ref) {
  var configDir = _ref.configDir,
      babelOptions = _ref.babelOptions,
      entries = _ref.entries;
  var entriesMeta = {
    iframe: {
      headHtmlSnippet: (0, _utils2.getPreviewHeadHtml)(configDir, process.env),
      bodyHtmlSnippet: (0, _utils2.getPreviewBodyHtml)()
    },
    manager: {
      headHtmlSnippet: (0, _utils2.getManagerHeadHtml)(configDir, process.env)
    }
  };
  return {
    mode: 'production',
    bail: true,
    devtool: '#cheap-module-source-map',
    entry: entries,
    output: {
      filename: 'static/[name].[chunkhash].bundle.js',
      // Here we set the publicPath to ''.
      // This allows us to deploy storybook into subpaths like GitHub pages.
      // This works with css and image loaders too.
      // This is working for storybook since, we don't use pushState urls and
      // relative URLs works always.
      publicPath: ''
    },
    plugins: (0, _toConsumableArray2.default)(Object.keys(entries).map(function (e) {
      return new _htmlWebpackPlugin.default({
        filename: "".concat(e === 'manager' ? 'index' : e, ".html"),
        excludeChunks: Object.keys(entries).filter(function (i) {
          return i !== e;
        }),
        chunksSortMode: 'none',
        alwaysWriteToDisk: true,
        inject: false,
        templateParameters: function templateParameters(compilation, files, options) {
          return (0, _objectSpread2.default)({
            compilation: compilation,
            files: files,
            options: options,
            version: _package.version
          }, entriesMeta[e]);
        },
        template: require.resolve("../templates/index.ejs")
      });
    })).concat([new _webpack.default.DefinePlugin((0, _utils.loadEnv)({
      production: true
    })), new _webpack.default.DefinePlugin((0, _universalDotenv.getEnvironment)().webpack), new _dotenvWebpack.default({
      silent: true
    })]),
    module: {
      rules: [{
        test: /\.jsx?$/,
        use: [{
          loader: 'babel-loader',
          options: babelOptions
        }],
        include: _utils.includePaths,
        exclude: _utils.excludePaths
      }, {
        test: /\.md$/,
        use: [{
          loader: require.resolve('raw-loader')
        }]
      }]
    },
    resolve: {
      // Since we ship with json-loader always, it's better to move extensions to here
      // from the default config.
      extensions: ['.js', '.jsx', '.json'],
      // Add support to NODE_PATH. With this we could avoid relative path imports.
      // Based on this CRA feature: https://github.com/facebookincubator/create-react-app/issues/253
      modules: ['node_modules'].concat(_utils.nodePaths),
      alias: {
        '@babel/runtime': (0, _utils.getBabelRuntimePath)()
      }
    },
    optimization: {
      // Automatically split vendor and commons for preview bundle
      // https://twitter.com/wSokra/status/969633336732905474
      splitChunks: {
        chunks: function chunks(chunk) {
          return chunk.name !== 'manager';
        }
      },
      // Keep the runtime chunk seperated to enable long term caching
      // https://twitter.com/wSokra/status/969679223278505985
      runtimeChunk: true
    }
  };
};

exports.default = _default;